com.timezynk.scheduler

An idiomatic Quartz wrapper for Clojure.

An idiomatic Quartz wrapper for Clojure.
raw docstring

startclj

(start)

Start the Quartz scheduler if not already done so.

Start the Quartz scheduler if not already done so.
sourceraw docstring

stopclj

(stop)

If started, stop the scheduler.

If started, stop the scheduler.
sourceraw docstring

with-schedulecljmacro

(with-schedule &
               :name
               <string>
               :second
               <string>
               :minute
               <string>
               :hour
               <string>
               :day
               <string>
               :month
               <string>
               :weekday
               <string>
               :year
               <string>
               ())

Create a new schedule. Parameters are first a set of optional keyworded strings, followed by executable expressions.

Omitting all optional parameters creates an unnamed schedule that runs on the hour.

ParameterDescription
:nameoptional string Schedule name.
:secondoptional string
:minuteoptional string
:houroptional string
:dayoptional string
:monthoptional string
:weekdayoptional string
:yearoptional string
bodyExpressions following parameters. The work to be done.

Returns

Log output side effect.

Examples

Default schedule, running on the hour:

(with-schedule
  (do-something))

A named schedule running at 02:00 on Sundays:

(with-schedule
  :name    "Schedule Name"
  :hour    "2"
  :weekday "SUN"
  (do-something)
  (do-something-more))
Create a new schedule. Parameters are first a set of optional `keyword`ed strings, followed by executable expressions.

Omitting all optional parameters creates an unnamed schedule that runs on the hour.

 | Parameter    | Description
 | ---          | ---
 | `:name`      | `optional string` Schedule name.
 | `:second`    | `optional string`
 | `:minute`    | `optional string`
 | `:hour`      | `optional string`
 | `:day`       | `optional string`
 | `:month`     | `optional string`
 | `:weekday`   | `optional string`
 | `:year`      | `optional string`
 | `body`       | Expressions following parameters. The work to be done.

 **Returns**

 Log output side effect.

 **Examples**

 Default schedule, running on the hour:
 ```clojure
 (with-schedule
   (do-something))
 ```
 
 A named schedule running at 02:00 on Sundays:
 ```clojure
 (with-schedule
   :name    "Schedule Name"
   :hour    "2"
   :weekday "SUN"
   (do-something)
   (do-something-more))
 ```
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries